==> dyld-46.9.tar.gz: dyld-46.9/unit-tests/test-cases/big-jump-table/funcs.c <==
/*
 * Copyright (c) 2006 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

#include "foo.h"

static void __attribute__((constructor)) myinit()
{
	foo002();
	foo003();
	foo004();
	foo005();
	foo006();
	foo007();
	foo008();
	foo009();
	foo010();
	foo011();
	foo012();
	foo013();
	foo014();
	foo015();
	foo016();
	foo017();
	foo018();
	foo019();
	foo020();
	foo021();
	foo022();
	foo023();
	foo024();
	foo025();
	foo026();
	foo027();
	foo028();
	foo029();
	foo030();
	foo031();
	foo032();
	foo033();
	foo034();
	foo035();
	foo036();
	foo037();
	foo038();
	foo039();
	foo040();
	foo041();
	foo042();
	foo043();
	foo044();
	foo045();
	foo046();
	foo047();
	foo048();
	foo049();
	foo050();
	foo051();
	foo052();
	foo053();
	foo054();
	foo055();
	foo056();
	foo057();
	foo058();
	foo059();
	foo060();
	foo061();
	foo062();
	foo063();
	foo064();
	foo065();
	foo066();
	foo067();
	foo068();
	foo069();
	foo070();
	foo071();
	foo072();
	foo073();
	foo074();
	foo075();
	foo076();
	foo077();
	foo078();
	foo079();
	foo080();
	foo081();
	foo082();
	foo083();
	foo084();
	foo085();
	foo086();
	foo087();
	foo088();
	foo089();
	foo090();
	foo091();
	foo092();
	foo093();
	foo094();
	foo095();
	foo096();
	foo097();
	foo098();
	foo099();
	foo100();
	foo101();
	foo102();
	foo103();
	foo104();
	foo105();
	foo106();
	foo107();
	foo108();
	foo109();
	foo110();
	foo111();
	foo112();
	foo113();
	foo114();
	foo115();
	foo116();
	foo117();
	foo118();
	foo119();
	foo120();
	foo121();
	foo122();
	foo123();
	foo124();
	foo125();
	foo126();
	foo127();
	foo128();
	foo129();
	foo130();
	foo131();
	foo132();
	foo133();
	foo134();
	foo135();
	foo136();
	foo137();
	foo138();
	foo139();
	foo140();
	foo141();
	foo142();
	foo143();
	foo144();
	foo145();
	foo146();
	foo147();
	foo148();
	foo149();
	foo150();
	foo151();
	foo152();
	foo153();
	foo154();
	foo155();
	foo156();
	foo157();
	foo158();
	foo159();
	foo160();
	foo161();
	foo162();
	foo163();
	foo164();
	foo165();
	foo166();
	foo167();
	foo168();
	foo169();
	foo170();
	foo171();
	foo172();
	foo173();
	foo174();
	foo175();
	foo176();
	foo177();
	foo178();
	foo179();
	foo180();
	foo181();
	foo182();
	foo183();
	foo184();
	foo185();
	foo186();
	foo187();
	foo188();
	foo189();
	foo190();
	foo191();
	foo192();
	foo193();
	foo194();
	foo195();
	foo196();
	foo197();
	foo198();
	foo199();
	foo200();
	foo201();
	foo202();
	foo203();
	foo204();
	foo205();
	foo206();
	foo207();
	foo208();
	foo209();
	foo210();
	foo211();
	foo212();
	foo213();
	foo214();
	foo215();
	foo216();
	foo217();
	foo218();
	foo219();
	foo220();
	foo221();
	foo222();
	foo223();
	foo224();
	foo225();
	foo226();
	foo227();
	foo228();
	foo229();
	foo230();
	foo231();
	foo232();
	foo233();
	foo234();
	foo235();
	foo236();
	foo237();
	foo238();
	foo239();
	foo240();
	foo241();
	foo242();
	foo243();
	foo244();
	foo245();
	foo246();
	foo247();
	foo248();
	foo249();
	foo250();
	foo251();
	foo252();
	foo253();
	foo254();
	foo255();
	foo256();
	foo257();
	foo258();
	foo259();
	foo260();
	foo261();
	foo262();
	foo263();
	foo264();
	foo265();
	foo266();
	foo267();
	foo268();
	foo269();
	foo270();
	foo271();
	foo272();
	foo273();
	foo274();
	foo275();
	foo276();
	foo277();
	foo278();
	foo279();
	foo280();
	foo281();
	foo282();
	foo283();
	foo284();
	foo285();
	foo286();
	foo287();
	foo288();
	foo289();
	foo290();
	foo291();
	foo292();
	foo293();
	foo294();
	foo295();
	foo296();
	foo297();
	foo298();
	foo299();
	foo300();
	foo301();
	foo302();
	foo303();
	foo304();
	foo305();
	foo306();
	foo307();
	foo308();
	foo309();
	foo310();
	foo311();
	foo312();
	foo313();
	foo314();
	foo315();
	foo316();
	foo317();
	foo318();
	foo319();
	foo320();
	foo321();
	foo322();
	foo323();
	foo324();
	foo325();
	foo326();
	foo327();
	foo328();
	foo329();
	foo330();
	foo331();
	foo332();
	foo333();
	foo334();
	foo335();
	foo336();
	foo337();
	foo338();
	foo339();
	foo340();
	foo341();
	foo342();
	foo343();
	foo344();
	foo345();
	foo346();
	foo347();
	foo348();
	foo349();
	foo350();
	foo351();
	foo352();
	foo353();
	foo354();
	foo355();
	foo356();
	foo357();
	foo358();
	foo359();
	foo360();
	foo361();
	foo362();
	foo363();
	foo364();
	foo365();
	foo366();
	foo367();
	foo368();
	foo369();
	foo370();
	foo371();
	foo372();
	foo373();
	foo374();
	foo375();
	foo376();
	foo377();
	foo378();
	foo379();
	foo380();
	foo381();
	foo382();
	foo383();
	foo384();
	foo385();
	foo386();
	foo387();
	foo388();
	foo389();
	foo390();
	foo391();
	foo392();
	foo393();
	foo394();
	foo395();
	foo396();
	foo397();
	foo398();
	foo399();
	foo400();
	foo401();
	foo402();
	foo403();
	foo404();
	foo405();
	foo406();
	foo407();
	foo408();
	foo409();
	foo410();
	foo411();
	foo412();
	foo413();
	foo414();
	foo415();
	foo416();
	foo417();
	foo418();
	foo419();
	foo420();
	foo421();
	foo422();
	foo423();
	foo424();
	foo425();
	foo426();
	foo427();
	foo428();
	foo429();
	foo430();
	foo431();
	foo432();
	foo433();
	foo434();
	foo435();
	foo436();
	foo437();
	foo438();
	foo439();
	foo440();
	foo441();
	foo442();
	foo443();
	foo444();
	foo445();
	foo446();
	foo447();
	foo448();
	foo449();
	foo450();
	foo451();
	foo452();
	foo453();
	foo454();
	foo455();
	foo456();
	foo457();
	foo458();
	foo459();
	foo460();
	foo461();
	foo462();
	foo463();
	foo464();
	foo465();
	foo466();
	foo467();
	foo468();
	foo469();
	foo470();
	foo471();
	foo472();
	foo473();
	foo474();
	foo475();
	foo476();
	foo477();
	foo478();
	foo479();
	foo480();
	foo481();
	foo482();
	foo483();
	foo484();
	foo485();
	foo486();
	foo487();
	foo488();
	foo489();
	foo490();
	foo491();
	foo492();
	foo493();
	foo494();
	foo495();
	foo496();
	foo497();
	foo498();
	foo499();
	foo500();
	foo501();
	foo502();
	foo503();
	foo504();
	foo505();
	foo506();
	foo507();
	foo508();
	foo509();
	foo510();
	foo511();
	foo512();
	foo513();
	foo514();
	foo515();
	foo516();
	foo517();
	foo518();
	foo519();
	foo520();
	foo521();
	foo522();
	foo523();
	foo524();
	foo525();
	foo526();
	foo527();
	foo528();
	foo529();
	foo530();
	foo531();
	foo532();
	foo533();
	foo534();
	foo535();
	foo536();
	foo537();
	foo538();
	foo539();
	foo540();
	foo541();
	foo542();
	foo543();
	foo544();
	foo545();
	foo546();
	foo547();
	foo548();
	foo549();
	foo550();
	foo551();
	foo552();
	foo553();
	foo554();
	foo555();
	foo556();
	foo557();
	foo558();
	foo559();
	foo560();
	foo561();
	foo562();
	foo563();
	foo564();
	foo565();
	foo566();
	foo567();
	foo568();
	foo569();
	foo570();
	foo571();
	foo572();
	foo573();
	foo574();
	foo575();
	foo576();
	foo577();
	foo578();
	foo579();
	foo580();
	foo581();
	foo582();
	foo583();
	foo584();
	foo585();
	foo586();
	foo587();
	foo588();
	foo589();
	foo590();
	foo591();
	foo592();
	foo593();
	foo594();
	foo595();
	foo596();
	foo597();
	foo598();
	foo599();
	foo600();
	foo601();
	foo602();
	foo603();
	foo604();
	foo605();
	foo606();
	foo607();
	foo608();
	foo609();
	foo610();
	foo611();
	foo612();
	foo613();
	foo614();
	foo615();
	foo616();
	foo617();
	foo618();
	foo619();
	foo620();
	foo621();
	foo622();
	foo623();
	foo624();
	foo625();
	foo626();
	foo627();
	foo628();
	foo629();
	foo630();
	foo631();
	foo632();
	foo633();
	foo634();
	foo635();
	foo636();
	foo637();
	foo638();
	foo639();
	foo640();
	foo641();
	foo642();
	foo643();
	foo644();
	foo645();
	foo646();
	foo647();
	foo648();
	foo649();
	foo650();
	foo651();
	foo652();
	foo653();
	foo654();
	foo655();
	foo656();
	foo657();
	foo658();
	foo659();
	foo660();
	foo661();
	foo662();
	foo663();
	foo664();
	foo665();
	foo666();
	foo667();
	foo668();
	foo669();
	foo670();
	foo671();
	foo672();
	foo673();
	foo674();
	foo675();
	foo676();
	foo677();
	foo678();
	foo679();
	foo680();
	foo681();
	foo682();
	foo683();
	foo684();
	foo685();
	foo686();
	foo687();
	foo688();
	foo689();
	foo690();
	foo691();
	foo692();
	foo693();
	foo694();
	foo695();
	foo696();
	foo697();
	foo698();
	foo699();
	foo700();
	foo701();
	foo702();
	foo703();
	foo704();
	foo705();
	foo706();
	foo707();
	foo708();
	foo709();
	foo710();
	foo711();
	foo712();
	foo713();
	foo714();
	foo715();
	foo716();
	foo717();
	foo718();
	foo719();
	foo720();
	foo721();
	foo722();
	foo723();
	foo724();
	foo725();
	foo726();
	foo727();
	foo728();
	foo729();
	foo730();
	foo731();
	foo732();
	foo733();
	foo734();
	foo735();
	foo736();
	foo737();
	foo738();
	foo739();
	foo740();
	foo741();
	foo742();
	foo743();
	foo744();
	foo745();
	foo746();
	foo747();
	foo748();
	foo749();
	foo750();
	foo751();
	foo752();
	foo753();
	foo754();
	foo755();
	foo756();
	foo757();
	foo758();
	foo759();
	foo760();
	foo761();
	foo762();
	foo763();
	foo764();
	foo765();
	foo766();
	foo767();
	foo768();
	foo769();
	foo770();
	foo771();
	foo772();
	foo773();
	foo774();
	foo775();
	foo776();
	foo777();
	foo778();
	foo779();
	foo780();
	foo781();
	foo782();
	foo783();
	foo784();
	foo785();
	foo786();
	foo787();
	foo788();
	foo789();
	foo790();
	foo791();
	foo792();
	foo793();
	foo794();
	foo795();
	foo796();
	foo797();
	foo798();
	foo799();
	foo800();
	foo801();
	foo802();
	foo803();
	foo804();
	foo805();
	foo806();
	foo807();
	foo808();
	foo809();
	foo810();
	foo811();
	foo812();
	foo813();
#if CASE <= 4
	foo814();
#endif
#if CASE <= 3
	foo815();
#endif
#if CASE <= 2
	foo816();
#endif
#if CASE <= 1
	foo817();
#endif
}

==> dyld-655.1.1.tar.gz: dyld-655.1.1/unit-tests/test-cases/big-jump-table/funcs.c <==
/*
 * Copyright (c) 2006 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
#include <mach/mach_time.h>
#include <stdio.h>
#include "foo.h"

static void __attribute__((constructor)) myinit()
{
//	uint64_t t1 = mach_absolute_time();
	foo002();
	foo003();
	foo004();
	foo005();
	foo006();
	foo007();
	foo008();
	foo009();
	foo010();
	foo011();
	foo012();
	foo013();
	foo014();
	foo015();
	foo016();
	foo017();
	foo018();
	foo019();
	foo020();
	foo021();
	foo022();
	foo023();
	foo024();
	foo025();
	foo026();
	foo027();
	foo028();
	foo029();
	foo030();
	foo031();
	foo032();
	foo033();
	foo034();
	foo035();
	foo036();
	foo037();
	foo038();
	foo039();
	foo040();
	foo041();
	foo042();
	foo043();
	foo044();
	foo045();
	foo046();
	foo047();
	foo048();
	foo049();
	foo050();
	foo051();
	foo052();
	foo053();
	foo054();
	foo055();
	foo056();
	foo057();
	foo058();
	foo059();
	foo060();
	foo061();
	foo062();
	foo063();
	foo064();
	foo065();
	foo066();
	foo067();
	foo068();
	foo069();
	foo070();
	foo071();
	foo072();
	foo073();
	foo074();
	foo075();
	foo076();
	foo077();
	foo078();
	foo079();
	foo080();
	foo081();
	foo082();
	foo083();
	foo084();
	foo085();
	foo086();
	foo087();
	foo088();
	foo089();
	foo090();
	foo091();
	foo092();
	foo093();
	foo094();
	foo095();
	foo096();
	foo097();
	foo098();
	foo099();
	foo100();
	foo101();
	foo102();
	foo103();
	foo104();
	foo105();
	foo106();
	foo107();
	foo108();
	foo109();
	foo110();
	foo111();
	foo112();
	foo113();
	foo114();
	foo115();
	foo116();
	foo117();
	foo118();
	foo119();
	foo120();
	foo121();
	foo122();
	foo123();
	foo124();
	foo125();
	foo126();
	foo127();
	foo128();
	foo129();
	foo130();
	foo131();
	foo132();
	foo133();
	foo134();
	foo135();
	foo136();
	foo137();
	foo138();
	foo139();
	foo140();
	foo141();
	foo142();
	foo143();
	foo144();
	foo145();
	foo146();
	foo147();
	foo148();
	foo149();
	foo150();
	foo151();
	foo152();
	foo153();
	foo154();
	foo155();
	foo156();
	foo157();
	foo158();
	foo159();
	foo160();
	foo161();
	foo162();
	foo163();
	foo164();
	foo165();
	foo166();
	foo167();
	foo168();
	foo169();
	foo170();
	foo171();
	foo172();
	foo173();
	foo174();
	foo175();
	foo176();
	foo177();
	foo178();
	foo179();
	foo180();
	foo181();
	foo182();
	foo183();
	foo184();
	foo185();
	foo186();
	foo187();
	foo188();
	foo189();
	foo190();
	foo191();
	foo192();
	foo193();
	foo194();
	foo195();
	foo196();
	foo197();
	foo198();
	foo199();
	foo200();
	foo201();
	foo202();
	foo203();
	foo204();
	foo205();
	foo206();
	foo207();
	foo208();
	foo209();
	foo210();
	foo211();
	foo212();
	foo213();
	foo214();
	foo215();
	foo216();
	foo217();
	foo218();
	foo219();
	foo220();
	foo221();
	foo222();
	foo223();
	foo224();
	foo225();
	foo226();
	foo227();
	foo228();
	foo229();
	foo230();
	foo231();
	foo232();
	foo233();
	foo234();
	foo235();
	foo236();
	foo237();
	foo238();
	foo239();
	foo240();
	foo241();
	foo242();
	foo243();
	foo244();
	foo245();
	foo246();
	foo247();
	foo248();
	foo249();
	foo250();
	foo251();
	foo252();
	foo253();
	foo254();
	foo255();
	foo256();
	foo257();
	foo258();
	foo259();
	foo260();
	foo261();
	foo262();
	foo263();
	foo264();
	foo265();
	foo266();
	foo267();
	foo268();
	foo269();
	foo270();
	foo271();
	foo272();
	foo273();
	foo274();
	foo275();
	foo276();
	foo277();
	foo278();
	foo279();
	foo280();
	foo281();
	foo282();
	foo283();
	foo284();
	foo285();
	foo286();
	foo287();
	foo288();
	foo289();
	foo290();
	foo291();
	foo292();
	foo293();
	foo294();
	foo295();
	foo296();
	foo297();
	foo298();
	foo299();
	foo300();
	foo301();
	foo302();
	foo303();
	foo304();
	foo305();
	foo306();
	foo307();
	foo308();
	foo309();
	foo310();
	foo311();
	foo312();
	foo313();
	foo314();
	foo315();
	foo316();
	foo317();
	foo318();
	foo319();
	foo320();
	foo321();
	foo322();
	foo323();
	foo324();
	foo325();
	foo326();
	foo327();
	foo328();
	foo329();
	foo330();
	foo331();
	foo332();
	foo333();
	foo334();
	foo335();
	foo336();
	foo337();
	foo338();
	foo339();
	foo340();
	foo341();
	foo342();
	foo343();
	foo344();
	foo345();
	foo346();
	foo347();
	foo348();
	foo349();
	foo350();
	foo351();
	foo352();
	foo353();
	foo354();
	foo355();
	foo356();
	foo357();
	foo358();
	foo359();
	foo360();
	foo361();
	foo362();
	foo363();
	foo364();
	foo365();
	foo366();
	foo367();
	foo368();
	foo369();
	foo370();
	foo371();
	foo372();
	foo373();
	foo374();
	foo375();
	foo376();
	foo377();
	foo378();
	foo379();
	foo380();
	foo381();
	foo382();
	foo383();
	foo384();
	foo385();
	foo386();
	foo387();
	foo388();
	foo389();
	foo390();
	foo391();
	foo392();
	foo393();
	foo394();
	foo395();
	foo396();
	foo397();
	foo398();
	foo399();
	foo400();
	foo401();
	foo402();
	foo403();
	foo404();
	foo405();
	foo406();
	foo407();
	foo408();
	foo409();
	foo410();
	foo411();
	foo412();
	foo413();
	foo414();
	foo415();
	foo416();
	foo417();
	foo418();
	foo419();
	foo420();
	foo421();
	foo422();
	foo423();
	foo424();
	foo425();
	foo426();
	foo427();
	foo428();
	foo429();
	foo430();
	foo431();
	foo432();
	foo433();
	foo434();
	foo435();
	foo436();
	foo437();
	foo438();
	foo439();
	foo440();
	foo441();
	foo442();
	foo443();
	foo444();
	foo445();
	foo446();
	foo447();
	foo448();
	foo449();
	foo450();
	foo451();
	foo452();
	foo453();
	foo454();
	foo455();
	foo456();
	foo457();
	foo458();
	foo459();
	foo460();
	foo461();
	foo462();
	foo463();
	foo464();
	foo465();
	foo466();
	foo467();
	foo468();
	foo469();
	foo470();
	foo471();
	foo472();
	foo473();
	foo474();
	foo475();
	foo476();
	foo477();
	foo478();
	foo479();
	foo480();
	foo481();
	foo482();
	foo483();
	foo484();
	foo485();
	foo486();
	foo487();
	foo488();
	foo489();
	foo490();
	foo491();
	foo492();
	foo493();
	foo494();
	foo495();
	foo496();
	foo497();
	foo498();
	foo499();
	foo500();
	foo501();
	foo502();
	foo503();
	foo504();
	foo505();
	foo506();
	foo507();
	foo508();
	foo509();
	foo510();
	foo511();
	foo512();
	foo513();
	foo514();
	foo515();
	foo516();
	foo517();
	foo518();
	foo519();
	foo520();
	foo521();
	foo522();
	foo523();
	foo524();
	foo525();
	foo526();
	foo527();
	foo528();
	foo529();
	foo530();
	foo531();
	foo532();
	foo533();
	foo534();
	foo535();
	foo536();
	foo537();
	foo538();
	foo539();
	foo540();
	foo541();
	foo542();
	foo543();
	foo544();
	foo545();
	foo546();
	foo547();
	foo548();
	foo549();
	foo550();
	foo551();
	foo552();
	foo553();
	foo554();
	foo555();
	foo556();
	foo557();
	foo558();
	foo559();
	foo560();
	foo561();
	foo562();
	foo563();
	foo564();
	foo565();
	foo566();
	foo567();
	foo568();
	foo569();
	foo570();
	foo571();
	foo572();
	foo573();
	foo574();
	foo575();
	foo576();
	foo577();
	foo578();
	foo579();
	foo580();
	foo581();
	foo582();
	foo583();
	foo584();
	foo585();
	foo586();
	foo587();
	foo588();
	foo589();
	foo590();
	foo591();
	foo592();
	foo593();
	foo594();
	foo595();
	foo596();
	foo597();
	foo598();
	foo599();
	foo600();
	foo601();
	foo602();
	foo603();
	foo604();
	foo605();
	foo606();
	foo607();
	foo608();
	foo609();
	foo610();
	foo611();
	foo612();
	foo613();
	foo614();
	foo615();
	foo616();
	foo617();
	foo618();
	foo619();
	foo620();
	foo621();
	foo622();
	foo623();
	foo624();
	foo625();
	foo626();
	foo627();
	foo628();
	foo629();
	foo630();
	foo631();
	foo632();
	foo633();
	foo634();
	foo635();
	foo636();
	foo637();
	foo638();
	foo639();
	foo640();
	foo641();
	foo642();
	foo643();
	foo644();
	foo645();
	foo646();
	foo647();
	foo648();
	foo649();
	foo650();
	foo651();
	foo652();
	foo653();
	foo654();
	foo655();
	foo656();
	foo657();
	foo658();
	foo659();
	foo660();
	foo661();
	foo662();
	foo663();
	foo664();
	foo665();
	foo666();
	foo667();
	foo668();
	foo669();
	foo670();
	foo671();
	foo672();
	foo673();
	foo674();
	foo675();
	foo676();
	foo677();
	foo678();
	foo679();
	foo680();
	foo681();
	foo682();
	foo683();
	foo684();
	foo685();
	foo686();
	foo687();
	foo688();
	foo689();
	foo690();
	foo691();
	foo692();
	foo693();
	foo694();
	foo695();
	foo696();
	foo697();
	foo698();
	foo699();
	foo700();
	foo701();
	foo702();
	foo703();
	foo704();
	foo705();
	foo706();
	foo707();
	foo708();
	foo709();
	foo710();
	foo711();
	foo712();
	foo713();
	foo714();
	foo715();
	foo716();
	foo717();
	foo718();
	foo719();
	foo720();
	foo721();
	foo722();
	foo723();
	foo724();
	foo725();
	foo726();
	foo727();
	foo728();
	foo729();
	foo730();
	foo731();
	foo732();
	foo733();
	foo734();
	foo735();
	foo736();
	foo737();
	foo738();
	foo739();
	foo740();
	foo741();
	foo742();
	foo743();
	foo744();
	foo745();
	foo746();
	foo747();
	foo748();
	foo749();
	foo750();
	foo751();
	foo752();
	foo753();
	foo754();
	foo755();
	foo756();
	foo757();
	foo758();
	foo759();
	foo760();
	foo761();
	foo762();
	foo763();
	foo764();
	foo765();
	foo766();
	foo767();
	foo768();
	foo769();
	foo770();
	foo771();
	foo772();
	foo773();
	foo774();
	foo775();
	foo776();
	foo777();
	foo778();
	foo779();
	foo780();
	foo781();
	foo782();
	foo783();
	foo784();
	foo785();
	foo786();
	foo787();
	foo788();
	foo789();
	foo790();
	foo791();
	foo792();
	foo793();
	foo794();
	foo795();
	foo796();
	foo797();
	foo798();
	foo799();
	foo800();
	foo801();
	foo802();
	foo803();
	foo804();
	foo805();
	foo806();
	foo807();
	foo808();
	foo809();
	foo810();
	foo811();
	foo812();
	foo813();
#if CASE <= 4
	foo814();
#endif
#if CASE <= 3
	foo815();
#endif
#if CASE <= 2
	foo816();
#endif
#if CASE <= 1
	foo817();
#endif

//	uint64_t t2 = mach_absolute_time();
//	fprintf(stderr, "total time = %lld\n", t2-t1);

}
